@@ -6,6 +6,9 @@ mod direct;
 mod from_str;
 mod serde;
 
+#[cfg(feature = "bitstring")]
+#[cfg(test)]
+mod bitstring_tests;
 #[cfg(test)]
 mod tests;
 
